@@ -1,10 +1,8 @@
 import astropy.coordinates as coord
 import astropy.constants as const
-import sunpy.coordinates.frames as frames
 import astropy.units as u
 
 import numpy as np
-import scipy.interpolate
 
 from pfsspy import coords
 
@@ -228,6 +226,14 @@ class FieldLine:
     def _solar_coord_index(self):
         return -1 - self._ss_coord_index
 
+    @property
+    def b_along_fline(self):
+        """
+        The magnetic field vectors along the field line.
+        """
+        coords = self.coords
+        return self._output.get_bvec(coords)
+
     @property
     @functools.lru_cache()
     def expansion_factor(self):
